@@ -10,14 +10,9 @@ import distro
 import pytest
 
 
-def _is_yum():
-    info = distro.linux_distribution()
-    return info[0] == 'CentOS Linux' and info[1].startswith('7')
-
-
 def _is_dnf():
     info = distro.linux_distribution()
-    return info[0] == 'CentOS Linux' and info[1].startswith('8')
+    return info[0].startswith('CentOS') and info[1].startswith('8')
 
 
 def test_network_ethernet(host):
@@ -92,6 +87,13 @@ def test_software_RAID(host):
     assert slaves == "loop0\nloop1"
 
 
+def test_luks(host):
+    # blkid returns an emptry string without root permissions
+    with host.sudo():
+        blkid = host.check_output('blkid /dev/md0')
+    assert 'TYPE="crypto_LUKS"' in blkid
+
+
 def test_sysctls(host):
     assert host.sysctl("fs.mount-max") == 99999
 
@@ -123,15 +125,7 @@ def test_timezone(host):
     assert "Pacific/Honolulu" in status
 
 
-@pytest.mark.parametrize('repo', ["base", "extras", "updates", "epel"])
-@pytest.mark.skipif(not _is_yum(), reason="Yum only supported on CentOS 7")
-def test_yum_local_package_mirrors(host, repo):
-    assert os.getenv('SITE_MIRROR_FQDN')
-    info = host.check_output("yum repoinfo %s", repo)
-    assert os.getenv('SITE_MIRROR_FQDN') in info
-
-
-@pytest.mark.parametrize('repo', ["AppStream", "BaseOS", "Extras", "epel",
+@pytest.mark.parametrize('repo', ["appstream", "baseos", "extras", "epel",
                                   "epel-modular"])
 @pytest.mark.skipif(not _is_dnf(), reason="DNF only supported on CentOS 8")
 def test_dnf_local_package_mirrors(host, repo):
@@ -145,13 +139,6 @@ def test_dnf_local_package_mirrors(host, repo):
     assert os.getenv('SITE_MIRROR_FQDN') in info
 
 
-@pytest.mark.skipif(not _is_yum(), reason="YUM only supported on CentOS 7")
-def test_yum_custom_package_repository_is_available(host):
-    with host.sudo():
-        host.check_output("yum -y install td-agent")
-    assert host.package("td-agent").is_installed
-
-
 @pytest.mark.skipif(not _is_dnf(), reason="DNF only supported on CentOS 8")
 def test_dnf_custom_package_repository_is_available(host):
     with host.sudo():
@@ -159,13 +146,6 @@ def test_dnf_custom_package_repository_is_available(host):
     assert host.package("td-agent").is_installed
 
 
-@pytest.mark.skipif(not _is_yum(), reason="YUM only supported on CentOS 7")
-def test_yum_cron(host):
-    assert host.package("yum-cron").is_installed
-    assert host.service("yum-cron").is_enabled
-    assert host.service("yum-cron").is_running
-
-
 @pytest.mark.skipif(not _is_dnf(), reason="DNF only supported on CentOS 8")
 def test_dnf_automatic(host):
     assert host.package("dnf-automatic").is_installed
